@@ -1,25 +1,23 @@
 from __future__ import print_function
 
 import argparse
-import sys
-import smtplib
-import re
-import os.path
 import email
 import email.iterators
+import os.path
+import re
+import smtplib
+import subprocess
+import sys
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
-import subprocess
-import six
-
 import markdown
 import pynliner
+import six
 
-from . import config
-from . import __version__
+from . import __version__, config
 
-__name__ = 'muttdown'
+__name__ = "muttdown"
 
 
 def get_charset_from_message_fragment(part):
@@ -40,34 +38,37 @@ def convert_one(part, config, charset):
             text = text.decode(charset)
         else:
             try:
-                text = text.decode('ascii')
+                text = text.decode("ascii")
             except UnicodeError:
                 # this is because of message.py:278 and seems like a hack
-                text = text.decode('raw-unicode-escape')
-    if not text.startswith('!m'):
-        return None
-    text = re.sub(r'\s*!m\s*', '', text, re.M)
-    if '\n-- \n' in text:
-        pre_signature, signature = text.split('\n-- \n')
-        md = markdown.markdown(pre_signature, output_format="html5")
+                text = text.decode("raw-unicode-escape")
+    if not config.assume_markdown:
+        if not text.startswith("!m"):
+            return None
+        text = re.sub(r"\s*!m\s*", "", text, re.M)
+    if "\n-- \n" in text:
+        pre_signature, signature = text.split("\n-- \n")
+        md = markdown.markdown(
+            pre_signature, extensions=["extra"], output_format="html5"
+        )
         md += '\n<div class="signature" style="font-size: small"><p>-- <br />'
-        md += '<br />'.join(signature.split('\n'))
-        md += '</p></div>'
+        md += "<br />".join(signature.split("\n"))
+        md += "</p></div>"
     else:
-        md = markdown.markdown(text)
+        md = markdown.markdown(text, extensions=["extra"])
     if config.css:
-        md = '<style>' + config.css + '</style>' + md
+        md = "<style>" + config.css + "</style>" + md
         md = pynliner.fromString(md)
-    message = MIMEText(md, 'html', _charset="UTF-8")
+    message = MIMEText(md, "html", _charset="UTF-8")
     return message
 
 
 def _move_headers(source, dest):
     for k, v in source.items():
         # mutt sometimes sticks in a fake bcc header
-        if k.lower() == 'bcc':
+        if k.lower() == "bcc":
             del source[k]
-        elif not (k.startswith('Content-') or k.startswith('MIME')):
+        elif not (k.startswith("Content-") or k.startswith("MIME")):
             dest.add_header(k, v)
             del source[k]
 
@@ -84,12 +85,12 @@ def convert_tree(message, config, indent=0, wrap_alternative=True, charset=None)
     if not message.is_multipart():
         # we're on a leaf
         converted = None
-        disposition = message.get('Content-Disposition', 'inline')
-        if disposition == 'inline' and ct in ('text/plain', 'text/markdown'):
+        disposition = message.get("Content-Disposition", "inline")
+        if disposition == "inline" and ct in ("text/plain", "text/markdown"):
             converted = convert_one(message, config, charset)
         if converted is not None:
             if wrap_alternative:
-                new_tree = MIMEMultipart('alternative')
+                new_tree = MIMEMultipart("alternative")
                 _move_headers(message, new_tree)
                 new_tree.attach(message)
                 new_tree.attach(converted)
@@ -98,19 +99,23 @@ def convert_tree(message, config, indent=0, wrap_alternative=True, charset=None)
                 return converted, True
         return message, False
     else:
-        if ct == 'multipart/signed':
+        if ct == "multipart/signed":
             # if this is a multipart/signed message, then let's just
             # recurse into the non-signature part
-            new_root = MIMEMultipart('alternative')
+            new_root = MIMEMultipart("alternative")
             if message.preamble:
                 new_root.preamble = message.preamble
             _move_headers(message, new_root)
             converted = None
             for part in message.get_payload():
-                if part.get_content_type() != 'application/pgp-signature':
-                    converted, did_conversion = convert_tree(part, config, indent=indent + 1,
-                                                             wrap_alternative=False,
-                                                             charset=charset)
+                if part.get_content_type() != "application/pgp-signature":
+                    converted, did_conversion = convert_tree(
+                        part,
+                        config,
+                        indent=indent + 1,
+                        wrap_alternative=False,
+                        charset=charset,
+                    )
                     if did_conversion:
                         new_root.attach(converted)
             new_root.attach(message)
@@ -122,7 +127,9 @@ def convert_tree(message, config, indent=0, wrap_alternative=True, charset=None)
                 new_root.preamble = message.preamble
             _move_headers(message, new_root)
             for part in message.get_payload():
-                part, did_this_conversion = convert_tree(part, config, indent=indent + 1, charset=charset)
+                part, did_this_conversion = convert_tree(
+                    part, config, indent=indent + 1, charset=charset
+                )
                 did_conversion |= did_this_conversion
                 new_root.attach(part)
             return new_root, did_conversion
@@ -130,8 +137,8 @@ def convert_tree(message, config, indent=0, wrap_alternative=True, charset=None)
 
 def process_message(mail, config):
     converted, did_any_markdown = convert_tree(mail, config)
-    if 'Bcc' in converted:
-        del converted['Bcc']
+    if "Bcc" in converted:
+        del converted["Bcc"]
     return converted
 
 
@@ -156,31 +163,40 @@ def read_message():
 
 
 def main(argv=None):
-    parser = argparse.ArgumentParser(prog='muttdown')
-    parser.add_argument('-v', '--version', action='version', version='%s %s' % (__name__, __version__))
+    parser = argparse.ArgumentParser(prog="muttdown")
     parser.add_argument(
-        '-c', '--config_file', default=os.path.expanduser('~/.muttdown.yaml'),
-        type=argparse.FileType('r'), required=False,
-        help='Path to YAML config file (default %(default)s)'
+        "-v", "--version", action="version", version="%s %s" % (__name__, __version__)
     )
     parser.add_argument(
-        '-p', '--print-message', action='store_true',
-        help='Print the translated message to stdout instead of sending it'
+        "-c",
+        "--config_file",
+        default=os.path.expanduser("~/.muttdown.yaml"),
+        type=argparse.FileType("r"),
+        required=False,
+        help="Path to YAML config file (default %(default)s)",
     )
-    parser.add_argument('-f', '--envelope-from', required=True)
     parser.add_argument(
-        '-s', '--sendmail-passthru', action='store_true',
-        help='Pass mail through to sendmail for delivery'
+        "-p",
+        "--print-message",
+        action="store_true",
+        help="Print the translated message to stdout instead of sending it",
     )
-    parser.add_argument('addresses', nargs='+')
+    parser.add_argument("-f", "--envelope-from", required=True)
+    parser.add_argument(
+        "-s",
+        "--sendmail-passthru",
+        action="store_true",
+        help="Pass mail through to sendmail for delivery",
+    )
+    parser.add_argument("addresses", nargs="+")
     args = parser.parse_args(argv)
 
     c = config.Config()
     try:
         c.load(args.config_file)
     except config.ConfigError as e:
-        sys.stderr.write('Error(s) in configuration %s:\n' % args.config_file.name)
-        sys.stderr.write(' - %s\n' % e.message)
+        sys.stderr.write("Error(s) in configuration %s:\n" % args.config_file.name)
+        sys.stderr.write(" - %s\n" % e.message)
         sys.stderr.flush()
         return 1
 
@@ -194,12 +210,12 @@ def main(argv=None):
     if args.print_message:
         print(rebuilt.as_string())
     elif args.sendmail_passthru:
-        cmd = c.sendmail.split() + ['-f', args.envelope_from] + args.addresses
+        cmd = c.sendmail.split() + ["-f", args.envelope_from] + args.addresses
 
         proc = subprocess.Popen(cmd, stdin=subprocess.PIPE, shell=False)
         msg = rebuilt.as_string()
         if sys.version_info > (3, 0):
-            msg = msg.encode('utf-8')
+            msg = msg.encode("utf-8")
         proc.stdin.write(msg)
         proc.stdin.close()
         proc.wait()
@@ -208,11 +224,11 @@ def main(argv=None):
         conn = smtp_connection(c)
         msg = rebuilt.as_string()
         if sys.version_info > (3, 0):
-            msg = msg.encode('utf-8')
+            msg = msg.encode("utf-8")
         conn.sendmail(args.envelope_from, args.addresses, msg)
         conn.quit()
     return 0
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main())
